aboutsummaryrefslogtreecommitdiff
path: root/misc/sword/files/patch-src::mgr::swmgr.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'misc/sword/files/patch-src::mgr::swmgr.cpp')
-rw-r--r--misc/sword/files/patch-src::mgr::swmgr.cpp30
1 files changed, 17 insertions, 13 deletions
diff --git a/misc/sword/files/patch-src::mgr::swmgr.cpp b/misc/sword/files/patch-src::mgr::swmgr.cpp
index 8fbcea84d1bb..fe0db28f4cb7 100644
--- a/misc/sword/files/patch-src::mgr::swmgr.cpp
+++ b/misc/sword/files/patch-src::mgr::swmgr.cpp
@@ -1,33 +1,37 @@
---- src/mgr/swmgr.cpp.orig Tue May 22 22:05:15 2001
-+++ src/mgr/swmgr.cpp Tue May 22 22:05:53 2001
-@@ -263,25 +263,25 @@
+--- src/mgr/swmgr.cpp.org Wed Dec 12 00:43:04 2001
++++ src/mgr/swmgr.cpp Wed Dec 12 00:44:39 2001
+@@ -268,21 +268,21 @@
}
- // check for systemwide /etc/sword.conf
-+ // check for systemwide /usr/local/etc/sword.conf
++ // check for systemwide _INSTDIR_/etc/sword.conf
+ #ifndef __VISUALC__
if (debug)
- cerr << "\nChecking for /etc/sword.conf...";
-+ cerr << "\nChecking for /usr/local/etc/sword.conf...";
++ cerr << "\nChecking for "_INSTDIR_"/etc/sword.conf...";
+ #endif
-- if ((fd = ::open("/etc/sword.conf", O_RDONLY)) > 0) {
-+ if ((fd = ::open("/usr/local/etc/sword.conf", O_RDONLY)) > 0) {
- ::close(fd);
+- if (!::access("/etc/sword.conf", 04)) {
++ if (!::access(_INSTDIR_"/etc/sword.conf", 04)) {
+ #ifndef __VISUALC__
if (debug)
cerr << "found\n";
+ #endif
- SWConfig etcconf("/etc/sword.conf");
-+ SWConfig etcconf("/usr/local/etc/sword.conf");
++ SWConfig etcconf(_INSTDIR_"/etc/sword.conf");
if ((entry = etcconf.Sections["Install"].find("DataPath")) != etcconf.Sections["Install"].end()) {
path = (*entry).second;
if (((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '\\') && ((*entry).second.c_str()[strlen((*entry).second.c_str())-1] != '/'))
- path += "/";
+@@ -290,7 +290,7 @@
+ #ifndef __VISUALC__
if (debug)
- cerr << "DataPath in /etc/sword.conf is set to: " << path;
-+ cerr << "DataPath in /usr/local/etc/sword.conf is set to: " << path;
++ cerr << "DataPath in "_INSTDIR_"/etc/sword.conf is set to: " << path;
+ #endif
- if (debug)
- cerr << "\nChecking for mods.conf in DataPath ";
+ #ifndef __VISUALC__